# TabbedSubpages -- Aggregates references content objects and tabs them
#
# (c) 2006 Martin F. Krafft <tabbedsubpages@pobox.madduck.net>
# distributed under the terms of the Artistic Licence.
# See the ./COPYING file in the source tree root for more information.
#
# THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
# WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
# MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.

__author__ = 'martin f. krafft'
__docformat__ = 'restructuredtext'

"""
"""
from cStringIO import StringIO
from Products.Archetypes.Extensions.utils import installTypes, install_subskin
from Products.CMFCore.utils import getToolByName

try:
  from Products.LinguaPlone.public import listTypes
except ImportError:
  from Products.Archetypes.public import listTypes

from Products.TabbedSubpages.config import *

def install_resources(portal, out):
  from Products.ResourceRegistries.config import CSSTOOLNAME, JSTOOLNAME

  tabbed_subpages_portal_type = TYPE_PARAMS['TabbedSubpages']['portal_type']
  expr = 'python:getattr(here, \'portal_type\', None) == \'%s\'' % tabbed_subpages_portal_type

  csstool = getToolByName(portal, CSSTOOLNAME)
  for (id, media) in RESOURCES_CSS.iteritems():
    csstool.manage_removeStylesheet(id=id)
    csstool.manage_addStylesheet(id=id, media=media,
      rel='stylesheet', enabled=True, cookable=True, expression=expr)
    print >> out, 'Registered CSS resource:', id

  jstool = getToolByName(portal, JSTOOLNAME)
  for id in RESOURCES_JS:
    jstool.manage_removeScript(id=id)
    jstool.manage_addScript(id=id,
      enabled=True, cookable=True, expression=expr)
    print >> out, 'Registered JS resource:', id

def uninstall_resources(portal, out):
  from Products.ResourceRegistries.config import CSSTOOLNAME, JSTOOLNAME

  csstool = getToolByName(portal, CSSTOOLNAME)
  for id in RESOURCES_CSS.iterkeys():
    csstool.manage_removeStylesheet(id=id)
    print >> out, 'Unregistered CSS resource:', id

  jstool = getToolByName(portal, JSTOOLNAME)
  for id in RESOURCES_JS:
    jstool.manage_removeScript(id=id)
    print >> out, 'Unregistered JS resource:', id

def install(portal):
  out = StringIO()

  installTypes(portal, out, listTypes(PROJECTNAME), PROJECTNAME)

  install_subskin(portal, out, GLOBALS)

  tabbed_subpages_portal_type = TYPE_PARAMS['TabbedSubpages']['portal_type']
  props_tool = getToolByName(portal, 'portal_properties')
  dpt = list(props_tool.site_properties.default_page_types)
  if tabbed_subpages_portal_type not in dpt:
    dpt.append(tabbed_subpages_portal_type)
    props_tool.site_properties.default_page_types = tuple(dpt)

  install_resources(portal, out)

  print >> out, "Successfully installed %s." % PROJECTNAME
  return out.getvalue()

def uninstall(portal):
  out = StringIO()

  try:
    tabbed_subpages_portal_type = TYPE_PARAMS['TabbedSubpages']['portal_type']
    props_tool = getToolByName(portal, 'portal_properties')
    dpt = list(props_tool.site_properties.default_page_types)
    dpt.remove(tabbed_subpages_portal_type)
    props_tool.site_properties.default_page_types = tuple(dpt)
  except ValueError: pass
  
  uninstall_resources(portal, out)

  print >> out, "Successfully uninstalled %s." % PROJECTNAME
  return out.getvalue()
