/*
 * TabbedSubpages -- Aggregates references content objects and tabs them
 *
 * (c) 2006 Martin F. Krafft <tabbedsubpages@pobox.madduck.net>
 * distributed under the terms of the Artistic Licence.
 * See the ./COPYING file in the source tree root for more information.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
 * MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

function TabbedSubpages_get_subpages() {
  var subpages = document.getElementById("subpages");
  if (!subpages || subpages.length == 0) return;
  return subpages.childNodes;
} 

function TabbedSubpages_hide_subpages() {
  var subpages = TabbedSubpages_get_subpages();
  if (!subpages || subpages.length == 0) return;
  for (i = 0; i < subpages.length; ++i) {
    if (subpages[i].className != "subpage") continue;
    subpages[i].style.display = "none";
  }
}

function TabbedSubpages_get_tabs() {
  var tabs = document.getElementById("subpageTabs");
  if (!tabs || tabs.length == 0) return;
  return tabs.firstChild.nextSibling.childNodes;
}

function TabbedSubpages_inactivate_tabs(ident) {
  var tabs = TabbedSubpages_get_tabs();
  if (!tabs || tabs.length == 0) return;
  for (i = 0; i < tabs.length; ++i) {
    if (!tabs[i].className || tabs[i].className.search("subpageTab") == -1)
      continue;
    tabs[i].className = "plain subpageTab";
  }
}

function TabbedSubpages_init_subpages(ident) {
  TabbedSubpages_hide_subpages(ident);
  var subpages = TabbedSubpages_get_subpages();
  if (!subpages || subpages.length == 0) return;
  for (i = 0; i < subpages.length; ++i) {
    if (subpages[i].className != "subpage") continue;
    subpages[i].style.display = "block";
    break;
  }
}

function TabbedSubpages_init_tabs() {
  TabbedSubpages_inactivate_tabs();
  var tabs = TabbedSubpages_get_tabs();
  if (!tabs || tabs.length == 0) return;
  for (i = 0; i < tabs.length; ++i) {
    if (!tabs[i].className || tabs[i].className.search("subpageTab") == -1)
      continue;
    tabs[i].className = "selected subpageTab";
    break;
  }
}

function TabbedSubpages_init() {
  TabbedSubpages_init_tabs();
  TabbedSubpages_init_subpages();
}

function TabbedSubpages_activate_subpage(subpage) {
  var subpage = document.getElementById("subpage-" + subpage);
  if (subpage) {
    TabbedSubpages_hide_subpages();
    subpage.style.display = "block";
  }
}

function TabbedSubpages_activate_tab(subpage) {
  var tab = document.getElementById("subpageTab-" + subpage);
  if (tab) {
    TabbedSubpages_inactivate_tabs();
    tab.className = "selected subpageTab";
  }
}

function TabbedSubpages_onclick_handler(subpage) {
  TabbedSubpages_activate_tab(subpage);
  TabbedSubpages_activate_subpage(subpage);
}

registerPloneFunction(TabbedSubpages_init)
